Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parseSelector = parseSelector;
exports.selectorToHTML = selectorToHTML;
exports.default = create;

var _isArray = require('vanillajs-helpers/isArray');

var _isArray2 = _interopRequireDefault(_isArray);

var _uniqueArray = require('vanillajs-helpers/uniqueArray');

var _uniqueArray2 = _interopRequireDefault(_uniqueArray);

var _toDOM = require('./toDOM');

var _toDOM2 = _interopRequireDefault(_toDOM);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const voidTags = ['area', 'base', 'br', 'col', 'embed', 'hr', 'img', 'input', 'keygen', 'link', 'meta', 'param', 'source', 'track', 'wbr'];
const elmExp = /^[a-z]+/;
const nameExp = /[a-z][\w\d-]*/i;
const idExp = new RegExp(`#${ nameExp.source }`, 'i');
const classExp = new RegExp(`\\.${ nameExp.source }`, 'ig');
const attrExp = new RegExp(`\\[(${ nameExp.source })(?:=([^\\]]+))?]`, 'g');

function parseSelector(selector) {
  if (!selector) {
    selector = '';
  }
  selector = `${ selector }`;

  let attributes = {};

  // Tag name
  let tagName = selector.match(elmExp);
  tagName = tagName ? tagName[0] : 'div';

  // Attribute experessions
  if (selector.indexOf('[') + 1) {
    selector = selector.replace(attrExp, (all, att, val) => {
      val = (val || '').replace(/^["']|["']$/g, '');

      const isID = att === 'id';
      const isClass = att === 'class';

      if (isID) {
        if (!attributes.id) {
          val = val.match(nameExp);
          if (val) {
            attributes.id = val[0];
          }
        }
      } else if (isClass) {
        val = val.split(/[ .#]+/).filter(cn => nameExp.test(cn));
        attributes.class = (attributes.class || []).concat(val);
      } else {
        if (!attributes[att]) {
          attributes[att] = [];
        }
        attributes[att].push(val.replace(/\\*"/g, '&quot;'));
      }

      return '';
    });
  }

  // ID
  const id = selector.indexOf('#') + 1 && selector.match(idExp);
  if (id) {
    attributes.id = id[0].substr(1);
  }

  // Class names
  const cns = selector.indexOf('.') + 1 && selector.match(classExp);

  if (cns) {
    attributes.class = cns.map(cn => cn.substr(1)).concat(attributes.class || []);
  }

  if (attributes.class) {
    attributes.class = (0, _uniqueArray2.default)(attributes.class).join(' ');
  }

  Object.keys(attributes).forEach(att => {
    if ((0, _isArray2.default)(attributes[att])) {
      attributes[att] = attributes[att].join(' ');
    }
  });

  return { tagName, attributes };
}

function selectorToHTML(selector) {
  const { tagName: tag, attributes } = parseSelector(selector);

  const atts = Object.keys(attributes).map(att => attributes[att] ? `${ att }="${ attributes[att] }"` : att);

  const start = `<${ tag }${ atts.length ? ` ${ atts.join(' ') }` : '' }>`;
  const end = voidTags.includes(tag) ? '' : `</${ tag }>`;

  return start + end;
}

function create(selector) {
  return (0, _toDOM2.default)(selectorToHTML(selector))[0];
}