Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = trigger;

var _eachWord = require('vanillajs-helpers/eachWord');

var _eachWord2 = _interopRequireDefault(_eachWord);

var _isFunction = require('vanillajs-helpers/isFunction');

var _isFunction2 = _interopRequireDefault(_isFunction);

var _isArray = require('vanillajs-helpers/isArray');

var _isArray2 = _interopRequireDefault(_isArray);

var _isString = require('vanillajs-helpers/isString');

var _isString2 = _interopRequireDefault(_isString);

var _isDOMNode = require('./isDOMNode');

var _isDOMNode2 = _interopRequireDefault(_isDOMNode);

var _isWindow = require('./isWindow');

var _isWindow2 = _interopRequireDefault(_isWindow);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Determine the method to create the correct CustomEvent object
// (IE 11 and below doesn't implement the object correctly)
const customEvent = (0, _isFunction2.default)(CustomEvent) ? (name, data) => {
  const options = { bubbles: true };
  if (typeof data !== 'undefined') {
    options.detail = data;
  }
  return new CustomEvent(name, options);
} : (name, data = null) => {
  const evt = document.createEvent('CustomEvent');
  evt.initCustomEvent(name, true, true, data);
  return evt;
};

/**
 * Trigger one or more events on a DOM element.
 * @param  {HTMLElement} [elm=document] - DOM element to trigger the event on
 * @param  {String|Array<String>} eventNames - Event names to trigger
 * @param  {Object} [data] - Extra data to add to the triggered event
 * @return {HTMLElement} - The 'elm' (or document)
 */
function trigger(elm, eventNames, data) {
  if ((0, _isString2.default)(elm)) {
    [elm, eventNames, data] = [document, elm, eventNames];
  }
  if (!(0, _isDOMNode2.default)(elm) && !(0, _isWindow2.default)(elm)) {
    elm = document;
  }

  if ((0, _isArray2.default)(eventNames)) {
    eventNames = eventNames.join();
  }
  (0, _eachWord2.default)(eventNames, name => elm.dispatchEvent(customEvent(name, data)), /[, ]+/);

  return elm;
}